@@ -54,6 +54,7 @@ class NoteTextMenu
 public:
   NoteTextMenu(const Glib::RefPtr<NoteBuffer> & buffer, UndoManager& undo_manager);
   void set_accels(utils::GlobalKeybinder & keybinder, const Glib::RefPtr<Gtk::AccelGroup> &);
+  void refresh_state();
 
   static void markup_label (Gtk::MenuItem & item);
 protected:
@@ -61,7 +62,6 @@ protected:
 
 private:
   void refresh_sizing_state();
-  void refresh_state();
   void link_clicked();
   void font_style_clicked(Gtk::CheckMenuItem * item);
   void font_size_activated(Gtk::RadioMenuItem *item);
@@ -251,7 +251,7 @@ private:
   void remove_accel_group(Gtk::Window &);
   void on_pin_status_changed(const Note &, bool);
   void on_pin_button_clicked();
-  void on_text_button_clicked(Gtk::Button *button);
+  void on_text_button_clicked();
 
   Note                        & m_note;
   std::string                   m_name;
